/*
JMP Clinical Analytical Process

Name: Findings Time Trends
Authors: Kelci Miclaus, SAS Institute Inc.

Description: 
      This process visualizes findings measurements for each subject across the timeline of the study.  
*/

/*
-----------------------------------------------------------
Copyright (C) 2010 SAS Institute, Inc. All rights reserved. 

Notice: 
The above copyright notice and this notice must appear in
any whole or partial copy of this code and any related
documentation. Permission to use, copy, and modify the
source code contained in this file is hereby granted, but
is limited to customers of SAS with a valid license for the
SAS software product with which this file was provided. 
Except as expressly set forth herein, the terms of such
license apply.
-----------------------------------------------------------
*/
*******************************************************************;
*     Clinical Variable Specification Block of CDISC Variable Usage;
*******************************************************************;
/*    
$CVS_START$
$INCF: {"LifeSciences\MacroLib\CDISCParms.sas","LifeSciences\MacroLib\FindingsMacros.sas"}$
$INCB: {{"FindingsV","CrossoverPeriods"},{"GeneralOptions","BaselineMeasurements","LabNormalization"}}$
$CMP: RSYS.Required Analysis Variables$ $UE: FINDINGS.xxSTRESN and FINDINGS.xxTESTCD$
   $NOTES: Each value of xxTESTCD must contain multiple xxSTRESN measurements per subject in order to plot trends.$
$CMP: OPV.{"Incorporate findings time points in plots","Yes"}$ $UE: FINDINGS.xxTPT or FINDINGS.xxTPTNUM$
   $NOTES: xxTPT ordered by xxTPTNUM if it exists.  This option is dependent on choosing VISITS as Time Scale for plots.  Option will be ignored if time point variables are not found$  
$CMP: OPV.{"Remove unscheduled visits","Yes"}$ $UE: FINDINGS.VISIT$
$CMP: OOUT$ $UE: FINDINGS.xxSTRESU$ $NOTES: Annotate plots with Standardized units on Y-axis measurement value.$
$CMP: OOUT$ $UE: FINDINGS.xxTEST$ $NOTES: Annotate plot titles with the Findings full test name.$
$CMP: OOUT$ $UE: FINDINGS.xxCAT$ $NOTES: Trend plots will be organized by values of category in outline boxes.$
$CMP: OOUT$ $UE: FINDINGS.xxSCAT$ $NOTES: Trend plots will be organized by values of sub category within category outline boxes.$
$CVS_STOP$
*/


*ProcessVariables;

%global StudyName InPath AInPath FDomain  FindDTests TrtUse DesignByVars TrtVar SubjectFilter WhereStmt MERGESUPPDOM  WhereForReports WhereTests 
TimeScaleT RemoveUVs VisitList TimePoints StartTimeTrend EndTimeTrend NormRefTrend 
TestColumnNames DisplayLogShft DisplayMeanTrends TrendMeanValue DisplayBarCounts DisplayErrorBars OverlayVisits PoolTreatments 
MeasurementValuesT DisplayLimits RestrictTimeView BaselineTimeWindow BaselineCalc VMBaselines TimeWindows
ImputeMissingValues IncSF PopulationSet OutPath ServerOutPath MacroPath
FindingsTimeTrends_OutData FindingsTimeTrends_OutMissDat FindingsTimeTrendsScript FDeltaDrop objReferenceName;

*ProcessBody;

%macro FindingsTimeTrends;
%let exerr = 0;
* initialization and argument checking;
%let ProcessName = FindingsTimeTrends; 

%include "&MacroPath./UtilityPathMacros.sas" / nosource;
%include "&MacroPath./UtilityMacros.sas" / nosource;

%include "&MacroPath./CDISCParms.sas";
*** Prepare ADSL ***;
%PREPADSL;
%if &exiterror %then %goto exit;

*** If Treatment or Comparison Variable to Use is Specified Below, reset NTrtPeriods to 1 ***;
%if %upcase(&TrtUse) =SPECIFIED BELOW or %UPcase(&TrtUse) = NONE %then %let NTrtPeriods = 1;
%if ^%length(&TrendMeanValue) %then %let TrendMeanValue = Mean;

%include "&MacroPath./FindingsMacros.sas";
%let WhereForReports=%nrbquote(&WhereStmt);
%global OutName;
%let OutName = &StudyName._&Fdomain;

%if &exiterror %then %goto exit;

%let ColorU = 0;
%if %UPcase(&TrtUse) = NONE %then %let TrtVar = USUBJID;
%else %do;
   %let TrtVar = &TrtName;
   proc freq data=&in_adsl(keep=&TrtName) noprint;
      tables &TrtName / out=fc;
      where not missing(&TrtName);
   run;

   %NObsVars(fc);
   %if &nobs < 2 %then %do;
      %let ColorU = 1;
   %end; 
%end;

%global LogShft TimeScale NormRef MeasurementValues;
%let LogShft = ;
%let NormRef = &NormRefTrend;
%let MeasurementValues = &MeasurementValuesT;
%let TimeScale = &TimeScaleT;
%let TestVar = &FDomain.TESTCD;
%let ResponseVar = &FDomain.STRESN;
%if %UPCASE(&FDomain) ne LB %then %do;
   %let LogShft = ;
   %let NormRef = ;
%end;

%if %Upcase(&FDomain) ne LB %then %let DisplayLimits = No;
%if ^%length(&OverlayVisits) %then %let OverlayVisits = No;

%if %upcase(&TimeScale)=WEEKS %then %do;
   %let TimeVar = STWK;
   %let TAxisLabel = Study Week;
   %let STvar = STWK;
   %let ENvar = STWK;
   %let TimeLabel = Study Week;  
%end;
%else %do;
   %let TimeVar = STDY;
   %let TAxisLabel = Study Day;
   %let STvar = STDY;
   %let ENvar = STDY;
   %let TimeLabel = Study Day;
%end;
   
%CheckBLTWsyntax(&BaselineTimeWindow);
%if &exiterror %then %goto exit;
   
%PrepOutDS(FindingsTimeTrends_OutData,OutDataName,&Fdomain,_ftt);

/* Macro performs error checking, checks existence of variables, determine flags, assign GroupSortVars and other macro variable values*/
%CheckFindingsData(&Fdomain);
%if &exiterror %then %goto exit;

%let COVar = ;
%if %UPcase(&TrtUse) ne NONE %then %do;
   %if &NTrtPeriods > 1 %then %do;
      %AssignCOTreatment(&Fdomain,&Fdomain,&Fdomain.DTC);
      %let COVar = &TrtName &TrtNameP;
   %end;
%end;
%else %do;
   %let NTrtPeriods = 1;
%end;

%if &_test_ %then %do;
	%let KeepTestNVar = &FDomain.TEST;
%end;
%else %do;
	%let KeepTestNVar = ;
	%let TestColumnNames = TESTCD;
	%put NOTE:  The &FDomain.TEST variable is not available, &FDomain.TESTCD values will be used for columns.;
%end;

%if %UPCASE(&NormRef) = NONE %then %let NormRef = ;
%if %upcase(&TimeScale) = VISITS %then %do;
   %if &fvisit = 0 and &fvisitn = 0 %then %do;
      %let TimeScale = Days;
      %let TimePoints = No;
   %end;
%end;
/* reset units back to 0 since transformation makes findings unitless*/
%if %index(%upcase(&MeasurementValues),PERCENT) or %length(&NormRef) %then %let funits = 0;

data _std;
   set &FDomain end=_last;
   where not missing(&ResponseVar);
   * compute standardized lab scores;
   %if %Upcase(&FDomain) = LB %then %do;
      %LabsNormalize(&ResponseVar,&NormRef,&LogShft);
   %end;
   %if %upcase(&TimeScale)=WEEKS %then %do;
      STWK = ceil(STDY/7);
      label STWK="Study Week";
   %end;
   %if &fcat %then %do;
      if missing(&FDomain.CAT) then &FDomain.CAT = "OTHER";
   %end;
   retain _mintime 99999999 _maxtime -999999999;
   if not missing(&TimeVar) then do;
      _mintime = min(_mintime,&TimeVar);
      _maxtime = max(_maxtime,&TimeVar);
   end;
   if _last then do;
         /* need this for baseline calculations whether they are subsetting plots or not */
      call symput('MinTime',trim(left(_mintime)));
      call symput('MaxTime',trim(left(_maxtime)));
      %if %Upcase(&RestrictTimeView) = YES %then %do;
         if &StartTimeTrend < _mintime then call symput('StartTimeTrend',trim(left(_mintime)));
         if &EndTimeTrend > _maxtime then call symput('EndTimeTrend',trim(left(_maxtime)));
      %end;
   end;
   %if %length(&NormRef) %then %do;
      &TestVar = trim(left(&TestVar))||"/&NormRef";
   %end;    
run;
proc datasets nolist;
   delete &Fdomain;
quit;run;

 %if %Upcase(&RestrictTimeView) = YES %then %do;
    * censor times if necessary;
    data _std;
      set _std;
      if &TimeVar < &StartTimeTrend then delete;
      else if &TimeVar > &EndTimeTrend then delete;
    run;
%end;

/*Up to this point, use LBDY for VISIT time Scale, now switch to VISIT */
%if %upcase(&TimeScale) = VISITS %then %do;
   %let TimeVar =;
   %if &fvisitn %then %let TimeVar = VISITNUM;
   %if &fvisit %then %let TimeVar = &TimeVar VISIT;
   
   %if %upcase(&TimePoints) = YES %then %do;
      %if &ftpt = 0 and &ftptn = 0 %then %let TimePoints = No;
      %if &ftptn %then %let TimeVar = &TimeVar &FDomain.TPTNUM;
      %if &ftpt %then %let TimeVar = &TimeVar &FDomain.TPT;
   %end;
%end;

proc sort data=_std;
   by USUBJID &COVar &TimeVar &GroupSortVars &TestVar &KeepTestNVar ;
run;

%if &blchg_ and ^%length(&BaselineTimeWindow) and %upcase(&MeasurementValues) = CHANGE FROM BASELINE %then %do;
   %let ResponseVar = &FDomain.BLCHG;
   %let RVarLab = Change from Baseline;
%end;
%else %if %index(%upcase(&MeasurementValues),CHANGE) or %index(%upcase(&MeasurementValues),PERCENT) %then %do;
   %let TimeWVar = ;
   %if %length(&BaselineTimeWindow) %then %do;
      %let TimeWindows = ;
      %CreateBaselineTW;
      %if &exerr %then %goto exit;
      %let TimeWindows = %str(&BaselineTimeWindow.[&MinTime,&MaxTime]);
      %let TimeWVar = TimeWindow;
      %put TimeWindows = &TimeWindows;
      %put BaselineFlagVar = &BLFlagVar;

      %if &blflag %then %do;
            %AddTimeWindows(domain=&Fdomain,indat=_std,outdat=_std,twb=&TimeWindows,tvar=&TimeWVar,findingscall=1,blflag=1);
      %end;
      %else %do;
            %AddTimeWindows(domain=&Fdomain,indat=_std,outdat=_std,twb=&TimeWindows,tvar=&TimeWVar,findingscall=1);     
      %end; 
   %end;

   %SplitBaselineTrial(&Fdomain, dset=_std, TimeV = &TimeWVar, doblchg = 1);
   %if &exerr %then %goto exit;
   
   proc sort data=_std;
      by USUBJID &COVar &TimeVar &GroupSortVars &TestVar &KeepTestNVar ;
   run;
%end;
%else %do;
   %let RVarLab = Observed Values;
%end;

* compute averages for each unique time point;
proc means data=_std noprint;
   by USUBJID &COVar &TimeVar &GroupSortVars &TestVar &KeepTestNVar ;
   var &ResponseVar;
   output out=_stdm mean=&ResponseVar;
run;

/* check if any tests are missing all values or only have one time point;*/
proc sort data=_stdm out=chktmp;
   by USUBJID &COVar &GroupSortVars &TestVar &KeepTestNVar;
run;

proc means data =chktmp noprint;
   by USUBJID &COVar  &GroupSortVars &TestVar &KeepTestNVar;
   var &ResponseVar;
   output out=chktmp nmiss=nmissing;
run;

data vals; set chktmp;
  nnonmiss = _freq_ - nmissing;
  if nnonmiss < 2 then delete;
run;

%nobsvars(vals);
%if &nobs = 0 %then %do;
   %put [MS_S_0115];
   %put ERROR:  There are no tests with measurements for at least two time points.  Time Trends cannot be plotted.;
   %let exiterror=1;
   %goto exit;
%end;

/*determine number of measurment levels and make macros for graphs;*/
proc sort data=vals nodupkey out=vals;
   by &GroupSortVars &TestVar;
run;

data vals;
   set vals end=_last;
   where not missing(&TestVar);
   call symput("testcdlev"||trim(left(_n_)),trim(left(&TestVar)));
   %if &_test_ %then call symput("testnamelev"||trim(left(_n_)),trim(left(&Fdomain.TEST)));;
   if _last then call symput("nvals", _n_);
run;

/* delete tests with less than two observed data points */
%do i=1 %to &nvals; 
   %if &i=1 %then %let teststrn = "&&testcdlev&i";
   %else %let teststrn = &teststrn, "&&testcdlev&i";
%end;
data _stdm; set _stdm;
   where &TestVar in (&teststrn);
run;

%if &funits or &fcat %then %do;
   /* get units of measurement */
   /* Get order of GroupVars */
   proc sort data = _std(keep=&GroupSortVars &TestVar %if &funits %then &Fdomain.STRESU;) out=gunits nodupkey;
      by &GroupSortVars &TestVar;
   run;
   
   /*kemicl:S1049452 - add check for unique values of test code across categories and group sort variables */
   %nobsvars(gunits);
   %let ntottest = &nobs;
   
   proc sort data = gunits out=uttests nodupkey;
      by &TestVar;
   run;
   %nobsvars(uttests);
   
   %if &nobs < &ntottest %then %do;
      %put [MS_S_0110];
      %put ERROR: Analysis cannot be completed because the &TestVar values are not unique across values of test category and/or subcategory.;
      %let exiterror = 1;
      %goto exit;
   %end;
   
   data gunits; 
      set gunits end=_last;
      where &TestVar in (&teststrn);
      %if &fcat %then %do;
         by &GroupSortVars;
      %end;
      %if &funits %then call symput("testunits"||trim(left(_n_)),trim(left(&Fdomain.STRESU)));;
      %if &fcat %then %do;
         if first.&FDomain.CAT then call symput("Cat"||trim(left(_n_)),trim(left(&FDomain.CAT)));
         call symput("TestCat"||trim(left(_n_)),trim(left(&FDomain.CAT)));         
         %if &fscat %then %do;
            if first.&FDomain.SCAT then call symput("SCat"||trim(left(_n_)),trim(left(&FDomain.SCAT)));
            call symput("TestSCat"||trim(left(_n_)),trim(left(&FDomain.SCAT)));
         %end;
      %end;
   run;
%end;

%if %upcase(&TimePoints) = YES %then %do;
   proc sort data = _std(keep =  &GroupSortVars  &Testvar %if &ftpt %then &Fdomain.TPT; %if &ftptn %then &Fdomain.TPTNUM;) out = testwtps nodupkey;
      by &Testvar %if &ftpt %then &Fdomain.TPT; %if &ftptn %then &Fdomain.TPTNUM;;
   run;
   
   data testwtps;
      set testwtps end=_last;
      where &TestVar in (&teststrn);
      by &TestVar;
      if first.&Testvar and last.&testVar then do;
         %if &ftpt %then %do;
            If missing(&Fdomain.TPT) then _DOTPT_ = 0;
         %end;
         %else %do;
            If missing(&FDomain.TPTNUM) then _DOTPT_ = 0;
         %end;
         else  _DOTPT_ = 1;
      end;
      else do;
      _DOTPT_ = 1;
      end;
   run;
   
   proc sort data =testwtps nodupkey;
      by &GroupSortVars &TestVar;
   run;
   
   data _null_;
      set testwtps end= _last;
      call symput("DoTTPTs"||trim(left(_n_)),trim(left(_DOTPT_)));
   run;
%end;

%let Limitlines = 0;
%if %upcase(&DisplayLimits) = YES %then %do;
   %if %sysfunc(findw(&LBVARS, LBSTNRHI)) > 0 and  %sysfunc(findw(&LBVARS, LBSTNRLO)) > 0 %then %do;
      %let LimitLines = 1;
      proc sort data = _std(keep=&GroupSortVars &TestVar LBSTNRHI LBSTNRLO) out=limits;
         by &GroupSortVars &TestVar;
      run;
      
      proc means data = limits noprint;
         by &GroupSortVars &TestVar;
         var LBSTNRHI LBSTNRLO;
         output out=minmaxs min(LBSTNRHI)=MinHi min(LBSTNRLO)=MinLo max(LBSTNRHI)=maxhi  max(LBSTNRLO) = maxlo;
      run;
      
      data minmaxs; 
         set minmaxs end=_last;
         where &TestVar in (&teststrn);
         call symput("minHi"||trim(left(_n_)),trim(left(MinHi)));
         call symput("maxHi"||trim(left(_n_)),trim(left(MaxHi)));
         call symput("minLo"||trim(left(_n_)),trim(left(MinLo)));
         call symput("maxLo"||trim(left(_n_)),trim(left(MaxLo)));
      run;
   %end;
%end;


* transpose to get into form required for pplot;
proc transpose data=_stdm out= outlib.&OutDataName(drop = _NAME_ _LABEL_) ;
   by USUBJID  &COVar &TimeVar ;
   var &ResponseVar;
   id &TestVar;
   idlabel &TestVar; 
run;

%if &syserr > 4 %then %do;
   %let exiterror = 1;
   %goto exit;
%end;

%nobsvars(outlib.&OutDataName);
%if &nobs = 0 %then %do;
   %put [MS_S_0116];
   %put ERROR: There are no observations available for time trend plotting in the analysis data set.;
   %put ERROR: To plot time trends, this process requires subjects with measurements taken at two or more time points.;
   %let exiterror=1;
   %goto exit;
%end;
   
%if &syserr > 4 %then %do;
   %let exiterror = 1;
   %goto exit;
%end;

/*
 * merge adsl;
 %let vflag =  %sysfunc(indexw(&ADSLVARS, VISIT, ' '));
 %let vnumflag = %sysfunc(indexw(&ADSLVARS, VISITNUM, ' '));
 %if &vflag or &vnumflag %then %let dropflag = 1;
 %else %let dropflag = 0;
 %let dropv = ;
 %if &vflag %then %let dropv = VISIT;
 %if &vnumflag %then %let dropv = &dropv VISITNUM;
 
 proc sql;
   create table outlib.&OutDataName(compress=yes) as
      select *
      from stdmt d1, &in_adsl %if &dropflag %then (drop = &dropv);  d2
      where d1.USUBJID=d2.USUBJID;
quit;

%nobsvars(OutLib.&OutDataName);
%if &nobs = 0 %then %do;
   %put [MS_S_0101];
   %put ERROR:  The merge of &in_lb and &in_adsl data sets resulted in 0 observations.  No subject identifiers match between the two data sets found in the defined Study folders.;
   %put ERROR:  Please check that the data sets in the Study folders are accurate.;
   %let exiterror = 1;
   %goto exit;
%end; 
*/

/* kemicl - added to calc TrtLev levels of treatment variable*/
%if %UPcase(&TrtUse) ne NONE %then %do;
   proc sort data=&in_adsl out=tvnum nodupkey;
      by &TrtVar;
   run;
   %NobsVars(tvnum);
   %let NTrtLev = &nobs;
%end;
%else %let NTrtLev = 1;

/* Get label for &FDomain.DY */
%DMFlags;
%if &exiterror %then %goto exit;
%DMLabels(&in_adsl);

%CheckStudyLevels;

%let TimeOLabel = ;
%let usevnum = 0;
%if %upcase(&TimeScale) = VISITS %then %do;
   %if &fvisit %then %do;
      %let TimeLabel = VISIT;
      %CheckLabel(OutLib.&OutDataName,TimeLabel);
      %if &fvisitn %then %do;
         %let TimeOLabel = VISITNUM;
         %CheckLabel(OutLib.&OutDataName,TimeOLabel);
      %end;       
   %end;
   %else %do;
      %let TimeLabel = VISITNUM;
      %CheckLabel(OutLib.&OutDataName,TimeLabel);
      %let usevnum = 1;
   %end;
%end;
%else %do;
   %let TimeLabel = &Timevar;
   %CheckLabel(OutLib.&OutDataName,TimeLabel);
%end;

%let usetpnum = 0;
%if %upcase(&TimePoints) = YES %then %do;
   %if &ftpt %then %do;
      %let TPLabel = &Fdomain.TPT;
      %CheckLabel(OutLib.&OutDataName,TPLabel);
   %end;
   %else %do;
      %let TPLabel = &Fdomain.TPTNUM;
      %CheckLabel(OutLib.&OutDataName,TPLabel);
      %let usetpnum = 1;
   %end;
   
   /* kemicl create ordered list for value ordering of Time Points */
   %if &ftpt and &ftptn %then %do;
      proc sort data=OutLib.&OutDataName(keep = &Fdomain.TPT &Fdomain.TPTNUM) out=tptorder nodupkey;
         by &Fdomain.TPTNUM &Fdomain.TPT;
      run;
      
      data tpts; 
          set tptorder end=_last;
          where not missing(&Fdomain.TPT);
          call symput("tptlev"||trim(left(_n_)),trim(left(&Fdomain.TPT)));
          if _last then call symput("ntpt", _n_);
      run;
      
      %nobsvars(tpts);
      %if &nobs = 0 %then %let TimePoints = No;
      %else %do;
         %let _tptList_ = ""%trim(%nrbquote(&tptlev1))"";
         %do i = 2 %to %eval(&ntpt);
            %let  _tptList_ = &_tptList_ , ""%trim(%nrbquote(&&tptlev&i))"";
         %end; 
      %end;
   %end; 
%end;

%if (&NTrtPeriods = 1 or  %upcase(&TimePoints) = NO ) %then %let OverlayVisits = No;
%if %upcase(&TimePoints) = YES and %upcase(&OverlayVisits)=YES %then %do;
   %let TimeLabel = &TPLabel;
   %let usevnum = 0;
%end;
   
%let SubjectLabel = USUBJID;
%CheckLabel(OutLib.&OutDataName,SubjectLabel);
   
%let odata = &in_adsl;
%include "&MacroPath./DesignByVars.sas";

/* Get Treatment Levels for Graph Builder Legend control */
proc sql noprint;         
	select count(distinct &TrtVar) into :ntrtVals
	from &odata;
quit;

%if %upcase(&PoolTreatments) = NO and &NTrtPeriods > 1 %then %do;
   %let TrtLabelM = &TrtLabelP;
%end;
%else %do;
   %let TrtLabelM = &TrtLabel;
%end;

 %if &syserr > 4 %then %do;
   %let exiterror = 1;
   %goto exit;
 %end;
 
* create JSL file;
%PrepOutFile(FindingsTimeTrendsScript,FindingsTimeTrendsScriptName,&StudyName &ProcessName Script for &Fdomain..jsl);
%global _mainjslfile_ FullAPName;
%let _mainjslfile_ = &FindingsTimeTrendsScript;
%let FullAPName=%str(Findings Time Trends (&FDomain));

   
%do i=1 %to &nvals;
	%if %upcase(&TestColumnNames) = TEST %then %let TestColName&i =  %nrbquote(&&testnamelev&i);
	%else %let TestColName&i =  %nrbquote(&&testcdlev&i);
	%let TestColName&i = %nrbquote(%sysfunc(transtrn(%nrbquote(&&TestColName&i), %str(%"), %str(\!%"))));
	%if &fcat %then %do;
		%if %symexist(Cat&i) %then %do; 
			%let j = &i;
			%let TestStrng&j = :Name(""%nrbquote(&&TestColName&i)"");
		%end;
		%else %do;
			%let TestStrng&j = &&TestStrng&j, :Name(""%nrbquote(&&TestColName&i)"");
		%end;
	%end;
%end;

* put JSL statements;
data _null_;
   file "&FindingsTimeTrendsScript" lrecl=32767 %if %nrbquote(&SYSENCODING) ne wlatin1 %then encoding="utf-8";;
   put "//!";
   put "Names Default to Here(1);";
   put "objRefNS = newNamespace();";
   put "jg:currentObjRefNamespaceName = objRefNS << getName;";
   put "objRefNS:DataList = {};";
   put "objRefNS:TabButtonList = {};";
   put "objRefNS:TabCodeList = {};";
   put "objRefNS:TabAfterCodeList = {};";
   put "objRefNS:CreateReportList = {};";
   put "objRefNS:NoteDomain = ""&FDomain"";";
      
   /*put "try(objRefNS:SubjectFilter=""\[&SubjectFilter]\"");";
   put "try(objRefNS:PopulationSet=""\[&PopulationSet]\"");";*/
   
      /* Try to Delete Domain Distribution Filter */
   %if %symexist(SFname) %then %do;
      %if %upcase(&SFname) = DISTRIBUTION_DRILL_DOWN %then %do;
         put "Include(""$CLINICAL_HOME\JSLFiles\SubjectFilterUtilityFunctions.jsl"");"; 
         put "try(DeleteSubjectFilterByName(""Distribution Drill Down"", empty(), ""&studyname""));";
      %end;
   %end;
      
   %let DomainWhereStmt = &WhereTests;
   %put &DomainWhereStmt;

	
   put "objRefNS:TabOpenList = {};";
   put "if(hostis(windows), _slash_ = ""\"", _slash_ = ""/"");";
   put "if(Host Is(Windows),";
   put "   JMPClinicalDir = ConvertFilePath(""$CLINICAL_HOME\"", absolute, windows),";
   put "   JMPClinicalDir = ConvertFilePath(""$CLINICAL_HOME/"", absolute, POSIX)";
   put ");";
   put "objRefNS:fsize = 600;";
   %if &NTrtPeriods = 1 %then %do;
      put "objRefNS:fssize = 600;";
      put "objRefNS:fsb = 100;";
      put "objRefNS:fse = 1000;";
   %end;
   %else %do;
      put "objRefNS:fssize = 175;";
      put "objRefNS:fsb = 50;";
      put "objRefNS:fse = 400;";
   %end;
   put "objRefNS:sdtmFolder = ""&InPath"";"; 
   
   put " objRefNS:OpendtExpr = Expr(If(IsEmpty(objRefNS:ftd),";
   put "    objRefNS:ftd = open(""&ClientOutPath.&OutDataName..sas7bdat"",invisible);";
   put "    reportRefNS:linkAnalysisTableToADSLTable(objRefNS:ftd);";
   put "      if (reportRefNS:reviewReplayIncludeDataPreprocessing,";     
   put "   	 jg:ApplyValueOrderToTables(EvalList({objRefNS:ftd}), ""&StudyName"");";
   put "    	Column(""&SubjectLabel"")<<Label(1);";
   put "    	Column(""&SubjectLabel"")<< Set Modeling Type( Nominal);";
   %if &usevnum %then %do;
      put "   	 Column(""&TimeLabel"")<< Set Modeling Type( Ordinal);";
   %end;
   %if &usetpnum %then %do;
      put "    	Column(""&TPLabel"")<< Set Modeling Type( Ordinal);";
   %end;    
   %if %upcase(&TimePoints) = YES and &ftpt and &ftptn %then %do;
      put "  	Column(""&TPLabel"")<< Set Property(""Value Ordering"",{&_tptList_});";
   %end; 
   %if %UPCase(&TrtUse) ne NONE and ^&ColorU %then %do;
      put "    objRefNS:ftd << Color Or Mark by Column(:Name(""&TrtLabel""));";
      put "    vcoloraa = Associative Array();";
      put "    For Each Row(vcoloraa[Column(""&SubjectLabel"")[Row()]] = Color Of( Row State( Row())));";
      put "    vcolors = vcoloraa << Get Values;";
      put "    For(";
      put "       v = 1;";
      put "       vc = vcoloraa <<first;, !IsEmpty(vc), vc = vcoloraa <<next(vc);";
      put "       v++;,";
      put "       vcolors[v] = Substitute(Expr(_label_ = _color_), Expr( _label_ ), vc, Expr( _color_ ), vcoloraa[vc])";
      put "    );";
      put "    Column(""&SubjectLabel"") << Set Property( ""Value Colors"", vcolors);";
   %end;
   %if &_test_ %then %do;
   	%do i=1 %to &nvals; 	
   		%if &_test_ and %upcase(&TestColumnNames) = TESTCD %then %do;
   			put "Column(""&&testcdlev&i"")<< Set Property(""SAS Label"",""&&testnamelev&i"");";
   		%end;
   		%else %if %upcase(&TestColumnNames) = TEST %then %do;
   			put "Column(""&&testcdlev&i"")<< Set Property(""SAS Label"",""&&testnamelev&i"");";   		
   			put "Column(""&&testcdlev&i"")<< Set Name(""&&testnamelev&i"");";
   		%end;
   		
   	%end;
   %end;
	%if &fcat %then %do;
		 %do i = 1 %to &nvals;
			%if %symexist(TestSCat&i) %then %do;
				%if %length(&&TestSCat&i) %then %do;
					put "Column(""&&TestColName&i"")<< Set Property(""SubCategory"",""&&TestSCat&i"");";
				%end;
			%end;
			%if %length(&&TestCat&i) %then %do;
				put "Column(""&&TestColName&i"")<< Set Property(""Category"",""&&TestCat&i"");";
			%end;				
			%if %symexist(Cat&i) %then %do;		
				put " objRefNS:ftd << Group Columns(""&&Cat&i"",{&&TestStrng&i});";
			%end;
		%end;  
	%end;   
   put "	);  //End of check for reportRefNS:reviewReplayIncludeDataPreprocessing";
   put "    objRefNS:dbv = {};";
   %do i=1 %to &ndbv;
      put "    InsertInto(objRefNS:dbv,Column(""&&dbv&i""));";
   %end; 
   put "  ,";  /*else for isempty*/;
   put "  Current Data Table(objRefNS:ftd);";
   put " );";  
   put ");";
   
   put "objRefNS:OpendtExpr;";
   
   %let trULN = %nrbquote(%LocaleGet(ULN_Text));
   %let trLLN = %nrbquote(%LocaleGet(LLN_Text));
   %let trMin = %nrbquote(%LocaleGet(Min_Text));
   %let trMax = %nrbquote(%LocaleGet(Max_Text));

	%let AvgTitleText = %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(AverageMeasurementsAcrossX_Text)), f1=%nrbquote(&TimeLabel)));
	%if %upcase(&TrendMeanValue) = GEOMETRIC MEAN %then %do;
		%let AvgTitleText = %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(AverageParenXParenMeasurementsAcrossX_Text)), 
		  f1=%nrbquote(%LocaleGet(GeometricMean_Text)), f2=%nrbquote(&TimeLabel)));
	%end;
	
   %if %symexist(mlchklow) or %symexist(mlchkhi) %then %do;
      %if &mlchklow or &mlchkhi %then %do;
         put "objRefNS:MLfunc=Function({},{default local},";
         put "    VListBox(";
         put "    objRefNS:mlwarn= TextBox(locale:get(""WarningResultsNotGenDueToMissValsGenByNorm_Text"")||"; 
         %if &mlchklow %then %do;
            put "    ""\!N\!N "" || locale:fill(locale:get(""AllLBSTNRLOMissOrZeroForLBTESTCDX_Text""), {""%trim(&chklln)""}) || ""\!N ""||";     
         %end;
         %if &mlchkhi %then %do;
            put "    ""\!N\!N "" || locale:fill(locale:get(""AllLBSTNRHIMissOrZeroForLBTESTCDX_Text""), {""%trim(&chkuln)""}) || ""\!N""||";      
         %end;    
         put "       "" "",";
         put "          <<Set Wrap(600), Set Font Size(11)";
         put "    );";  
         put "));";
         
         put 'InsertInto(objRefNS:DataList,{{""}});';
         put "InsertInto(objRefNS:TabButtonList, expr(locale:fill(locale:get(""XWarningMessage_Text""), {locale:get(""Findings_Text"")})));";
         put 'InsertInto(objRefNS:TabCodeList,expr(objRefNS:MLfunc()));';
         put 'InsertInto(objRefNS:TabAfterCodeList," ");';
         put 'InsertInto(objRefNS:TabOpenList,1);';
         put "InsertInto(objRefNS:CreateReportList,{{objRefNS:mlwarn}});";       
      %end;
   %end; 
   
   %if %Upcase(&DisplayMeanTrends) = YES %then %do;
      put "objRefNS:spfuncm=Function({},{default local},";
      put "objRefNS:OpendtExpr;";
      put "  VListBox(";
      %if %length(&COFlag) %then %do;
         put "objRefNS:COText = TextBox("" "" ||locale:get(""MultTrtPeriodsHaveBeenDetectedandDisplayed_Text""), <<Set Wrap(1000)),";
         put "objRefNS:COText = TextBox("" "" ||locale:get(""PreTrtHasBeenAssignedtoPeriodZero_Text""), <<Set Wrap(1000)),";
         %if &PMBase = 1 and %upcase(&MeasurementValuesT) ne OBSERVED RESULT %then %do; 
             put "objRefNS:COText = TextBox("" "" ||locale:get(""PeriodMatchedBaselinesHaveBeenDetectedandUsed_Text""), <<Set Wrap(1000)),";
         %end;
      %end;
      /* kemicl put back framesize sliders */
      put "       HListBox(TextBox("" "" || locale:get(""FrameSize_Text"")),";
      put "          frameSizeSliderbiv = SliderBox(num(100),num(1000),objRefNS:fsize,";
      %do i=1 %to &nvals;
         put "             try(objRefNS:gprepm&i = (objRefNS:gbm&i<<report));";
         put "          try(objRefNS:gprepm&i[framebox(1)]<<FrameSize(objRefNS:fsize,0.35*objRefNS:fsize));";
      %end;
      put "       )),";
      put " if(""&RVarLab"" == ""Change from Baseline"", trRVarLab = locale:get(""ChangefromBaseline_Text""),";
      put "    ""&RVarLab"" == ""Observed Values"", trRVarLab = locale:get(""ObservedResult_Text""),";
      put "    ""&RVarLab"" == ""PCT Change from Baseline"", trRVarLab = locale:get(""PCTChangefromBaseline_Text""),";
      put "    ""&RVarLab"" == ""Percent of Baseline"", trRVarLab = locale:get(""PercentofBaseline_Text""),";
      put "    trRVarLab = ""&RVarLab"");";        
      put " objRefNS:GBvlb = VlistBox(";
      %do i=1 %to &nvals;
         %if &fcat %then %do;
            %if %symexist(Cat&i) %then %do;
               put " OutlineBox(locale:fill(locale:get(""XTestCategory_Text""), {""&FDomain""}) || "" = &&Cat&i"",";
            %end;
            %if %symexist(SCat&i) %then %do;
               %if %length(&&SCat&i) %then %do;
                  put " TextBox(locale:fill(locale:get(""XTestSubcategory_Text""), {""&FDomain""}) || "" = &&Scat&i""),";
               %end;
            %end;
         %end;
            put "    objRefNS:vgbm&i = VlistBox(";
            put "    objRefNS:gbm&i = Graph Builder(";
            %if %upcase(&DisplayBarCounts) = YES %then %do;
					put "			Size(640,320),";
				%end;
            put "       Show Control Panel(0), Lock Scales( 0 ), AutoStretching(0),";
            put "       Where(!IsMissing(:Name(""&&TestColName&i""))),";
            put "       Variables(";
            put "          X(:Name(""&TimeLabel"")";
            %if %upcase(&OverlayVisits)=NO %then %do;
               %if %length(&TimeOLabel) %then %do;
                  put "          ,Order By( :Name(""&TimeOLabel""), Ascending)";
               %end;
               put "          ),";
               %if %upcase(&TimePoints) = YES %then %do;
                  %if &&DoTTPTs&i %then %do;
                     put "       X(:Name(""&TPLabel""), Position(1)),";
                  %end;
               %end;
            %end;
            %else %do;
               put "          ),";
            %end;
            put "          Y(:Name(""&&TestColName&i"")),";
            %if %upcase(&DisplayBarCounts) = YES %then %do;
            	put "          Y(:Name(""&&TestColName&i"")),";
            %end;
            %if %upcase(&SplitResults)=YES %then %do;
               %do j=1 %to &ndbv;
                  put "       Group Y(Column(""&&dbv&j"")),";
               %end;
            %end;    
            %if %UPCase(&TrtUse) ne NONE and ^&ColorU %then %do;
            put "          Overlay(:Name(""&TrtLabelM""))";
            %end;
            put "       ),";
            put "       Elements(";
            %if %upcase(&DisplayBarCounts) = YES %then %do;
	     			put "			   Position( 1, 1 ),";
				%end;
            %if %upcase(&TimePoints) = NO %then %do;
               put "          Line(X,Y,Legend(1), Row order(0), Summary Statistic(""&TrendMeanValue"")),";
               put "          Points(X,Y, Legend(2), Summary Statistic(""&TrendMeanValue"")";
            %end;
            %else %do;
               put "          Line(X(1), X(2),Y,Legend(1), Row order(0), Summary Statistic(""&TrendMeanValue"")),";
               put "          Points(X(1), X(2),Y, Legend(2),Summary Statistic(""&TrendMeanValue"")";
            %end;          
            %if %Upcase(&DisplayErrorBars) = YES %then %do;
               put "          ,Error Bars( ""Standard Error"" ),";
            %end;
            put "          )";
            put "       )";
     			%if %upcase(&DisplayBarCounts) = YES %then %do;
     			   put "       ,Elements(";
     			   put "			   Position( 1, 2 ),";
     			   %if %upcase(&TimePoints) = NO %then %do;
            		put "          Bar(X,Y, Legend(19), Summary Statistic(""N""))";
            	%end;
            	%else %do;
             		put "          Bar(X(1),X(2),Y, Legend(19), Summary Statistic(""N""))";
            	%end;   
            	put "			),";
            	put "			Relative Sizes( ""Y"", [2 1] )";

            %end;
            put "       ,SendToReport(";
            put "          Dispatch( {}, ""Graph Builder"", FrameBox, {Marker Size( 3 )} ),";
				put "				Dispatch({},""graph title"",TextEditBox,{Set Text( ""&AvgTitleText"" )})";
            %if &_test_ %then %do;
               put "          ,Dispatch({},""Graph Builder"",OutlineBox,";
               put "             {Set Title( locale:fill(locale:get(""XforX_Text""), {trRVarLab, ""&&testnamelev&i""}) )}";
               put "          )";   
            %end;
            %if %UPCASE(&DisplayLogShft) = YES %then %do;
               put "          ,Dispatch({},";
               put "             ""&&TestColName&i"",";
               put "             ScaleBox,{Scale(""Log"")}";
               put "          )";
            %end;
            %if %upcase(&TimePoints) = YES %then %do;
               %if &&DoTTPTs&i %then %do;
                  put "    ,Dispatch({},";
                  put "       ""&TimeLabel"",";
                  put "       ScaleBox, {Tick Font( size( 8 ) ), Rotated Labels( ""Perpendicular"" )}";
                  put "    )";         
               %end;
            %end; 
     			%if %upcase(&DisplayBarCounts) = YES %then %do;
     				put "					,Dispatch({},""400"",LegendBox,{Legend Position( {19, [-1]})})";
					put "					,Dispatch({}, ""400"", ScaleBox,";
					put "						{Legend Model(19,";
					%do ii = 0 %to %eval(&ntrtVals-1);
						put "						Properties( &ii, {Transparency( 0.8 )} ),";
					%end;
					put "						)}";
					put "					)";  
            	put "          ,Dispatch({},""Y 1 title"", TextEditBox, {Rotate Text(""Left"")})"; 
               put "          ,Dispatch( {}, ""Y 1 title"", TextEditBox, {Set Text(locale:get(""Count_Text""))})";
				%end;
            put "          ,Dispatch({},""Y title"", TextEditBox, {Rotate Text(""Left"")})";          
            %if &funits %then %do;
               put "          ,Dispatch( {}, ""Y title"", TextEditBox, {Set Text( ""&&TestColName&i (&&testunits&i)"" )} )";
            %end;           
            put "       )";
            put "    )),"; 
            * end for each graph builder plot;
            %if &i < &nvals and &fcat %then %do;
               %let ni = %eval(&i+1);
               %if %symexist(Cat&ni) %then %do;
                  put "   ),";  /* end each outline box for test category*/
               %end;
            %end;
         %if &i = &nvals and &fcat %then %do;
            put "    )";  /* close last outline box if xxCat used */
         %end;
      %end;
      put " ));"; /*end vlist */
      put ");";  /*end function*/   
      put 'InsertInto(objRefNS:DataList,{{"objRefNS:ftd"}});';
     %if ^%symexist(DOMAINLABEL_&FDomain) %then %let DOMAINLABEL_&FDomain = %nrbquote(&FDomain);
      put "InsertInto(objRefNS:TabButtonList, expr(locale:fill(locale:get(""XTreatmentTimeTrends_Text""),{""&&DOMAINLABEL_&FDomain""})));";
      put 'InsertInto(objRefNS:TabCodeList,expr(objRefNS:spfuncm()));';
      put 'InsertInto(objRefNS:TabAfterCodeList, " ");';
      put 'InsertInto(objRefNS:TabOpenList,1);';
      put "InsertInto(objRefNS:CreateReportList,{{objRefNS:GBvlb}});";
   %end;
   
   put "objRefNS:spfunc=Function({},{default local},";
   put "objRefNS:OpendtExpr;";
   put "HListBox(";
   put " VListBox(";
   put " objRefNS:GBvlb2 = VListBox(";
   /* kemicl put back framesize sliders */
      put "       HListBox(TextBox("" "" || locale:get(""FrameSize_Text"")),";
      put "          frameSizeSliderbiv = SliderBox(num(objRefNS:fsb),num(objRefNS:fse),objRefNS:fssize,";
      %do i=1 %to &nvals;
         put "             try(objRefNS:gprep&i = (objRefNS:gb&i<<report));";
         put "          try(objRefNS:gprep&i[framebox(1)]<<FrameSize(objRefNS:fssize,0.35*objRefNS:fssize));";
      %end;
   put "       )),";
   put " if(""&MeasurementValues"" == ""Observed Result"", trMeasurementValues = locale:get(""ObservedResult_Text""),";
   put "    ""&MeasurementValues"" == ""Change from Baseline"", trMeasurementValues = locale:get(""ChangefromBaseline_Text""),";
   put "    ""&MeasurementValues"" == ""Percent Change from Baseline"", trMeasurementValues = locale:get(""PercentChangefromBaseline_Text""),";
   put "    ""&MeasurementValues"" == ""Percent of Baseline"", trMeasurementValues = locale:get(""PercentofBaseline_Text""),";
   put "    trMeasurementValues = ""&MeasurementValues"");";      
            
   %do i=1 %to &nvals;
         %if &fcat %then %do;
            %if %symexist(Cat&i) %then %do;
               put " OutlineBox(locale:fill(locale:get(""XTestCategory_Text""), {""&FDomain""}) || "" = &&Cat&i"",";
            %end;
            %if %symexist(SCat&i) %then %do;
               %if %length(&&SCat&i) %then %do;
                  put " TextBox(locale:fill(locale:get(""XTestSubcategory_Text""), {""&FDomain""}) || "" = &&Scat&i""),";
               %end;
            %end;            
         %end;
         put "    objRefNS:vgb&i = VlistBox(";
         put "    objRefNS:gb&i = Graph Builder(";
         put "       Show Control Panel(0), Lock Scales( 1 ), AutoStretching(0),";
         put "       Where(!IsMissing(:Name(""&&TestColName&i""))),";
         %if &NTrtPeriods =1 %then %do;
            put " Show Legend(0), ";
         %end;
         put "       Variables(";
         put "          X(:Name(""&TimeLabel"")";
         %if %upcase(&OverlayVisits)=NO %then %do;
            %if %length(&TimeOLabel) %then %do;
               put "          ,Order By( :Name(""&TimeOLabel""), Ascending)";
            %end;
            put "          ),";
            %if %upcase(&TimePoints) = YES %then %do;
               %if &&DoTTPTs&i %then %do;
                  put "       X(:Name(""&TPLabel""), Position(1)),";
               %end;
            %end; 
         %end;
         %else %do;
            put "          ),";
         %end;
         put "          Y(:Name(""&&TestColName&i"")),";
         %if %upcase(&SplitResults)=YES %then %do;
            %do j=1 %to &ndbv;
               put "       Group Y(Column(""&&dbv&j"")),";
            %end;
         %end;
         %if &NTrtPeriods = 1 %then %do;
            put "          Overlay(:Name(""&SubjectLabel""))";
         %end;
         %else %do;
            put "          Wrap(:Name(""&SubjectLabel"")),";
            put "          Overlay(:Name(""&TrtLabel""))";
         %end;
         put "       ),";
         put "       Elements(";
         %if %upcase(&TimePoints) = YES %then %do;
            put "          Line(X(1),X(2),Y,Row order(0), Summary Statistic(""Mean""))";
         %end;
         %else %do;
            put "          Line(X,Y,Row order(0), Summary Statistic(""Mean""))";
         %end;
         put "       ),";
         put "    SendToReport(";
			put "				Dispatch({},""graph title"",TextEditBox,{Set Text( ""Subject Trends Across &TimeLabel"" )})";
         %if &_test_ %then %do;
            put "    ,Dispatch({},";
            put "       ""Graph Builder"",";
            put "       OutlineBox,";
            put "       {Set Title( locale:fill(locale:get(""XforX_Text""), {trMeasurementValues, ""&&testnamelev&i""}) )}";
            put "    )";
         %end;
         %if &LimitLines %then %do;
            %if %sysevalf(&&minHi&i ne .) or %sysevalf(&&maxHi&i ne .) %then %do;
               %if %sysevalf(&&minHi&i = &&maxHi&i) %then %do;
                  put "    ,Dispatch( {}, ""&&TestColName&i"", ScaleBox, {Add Ref Line( &&minHi&i, Dashed, ""Medium Dark Gray"", ""&trULN"" )})";
               %end;
               %else %do;
                  /*
                  %if &&minHi&i ne . %then %do;
                     put "    ,Dispatch( {}, ""&&TestColName&i"", ScaleBox, {Add Ref Line( &&minHi&i, Dashed, ""Medium Dark Gray"", ""&trMin &trULN"" )})";
                  %end;
                  */
                  %if %sysevalf(&&maxHi&i ne .) %then %do;
                     put "    ,Dispatch( {}, ""&&TestColName&i"", ScaleBox, {Add Ref Line( &&maxHi&i, Dashed, ""Medium Dark Gray"", ""&trMax &trULN"" )})";
                  %end; 
               %end;
            %end;
            %if %sysevalf(&&minLo&i ne .) or %sysevalf(&&maxLo&i ne .) %then %do;
               %if %sysevalf(&&minLo&i = &&maxLo&i) %then %do;
                  put "    ,Dispatch( {}, ""&&TestColName&i"", ScaleBox, {Add Ref Line( &&minLo&i, Dashed, ""Medium Dark Gray"", ""&trLLN"" )})";
               %end;
               %else %do;
                  %if %sysevalf(&&minLo&i ne .) %then %do;
                     put "    ,Dispatch( {}, ""&&TestColName&i"", ScaleBox, {Add Ref Line( &&minLo&i, Dashed, ""Medium Dark Gray"", ""&trMin &trLLN"" )})";
                  %end;
                  /*
                  %if &&maxLo&i ne . %then %do;
                     put "    ,Dispatch( {}, ""&&TestColName&i"", ScaleBox, {Add Ref Line( &&maxLo&i, Dashed, ""Medium Dark Gray"", ""&trMax &trLLN"" )})";
                  %end;
                  */
               %end;             
            %end;
         %end;
         %if %UPCASE(&DisplayLogShft) = YES %then %do;
            put "       ,Dispatch({},";
            put "          ""&&TestColName&i"",";
            put "          ScaleBox,{Scale(""Log"")}";
            put "       )";
         %end;
         put "          ,Dispatch({},""Y title"", TextEditBox, {Rotate Text(""Left"")})";
         %if &funits %then %do;
            put "          ,Dispatch( {}, ""Y title"", TextEditBox, {Set Text( ""&&TestColName&i (&&testunits&i)"" )} )";
         %end;
         %if %upcase(&TimePoints) = YES %then %do;
            %if &&DoTTPTs&i %then %do;
               put "    ,Dispatch({},";
               put "       ""&TimeLabel"",";
               put "       ScaleBox, {Tick Font( size( 8 ) ), Rotated Labels( ""Perpendicular"" )}";
               put "    )";         
            %end;
         %end;       
         put "    )";
         put "    )),";  /* end for each graph builder plot*/
         %if &i < &nvals and &fcat %then %do;
            %let ni = %eval(&i+1);
            %if %symexist(Cat&ni) %then %do;
               put "   ),";  /* end each outline box for test category*/
            %end;
         %end;
         %if &i = &nvals and &fcat %then %do;
            put "    )";  /* close last outline box if xxCat used */
         %end;       
   %end;
   put "    ),"; 
   put " )";  /* close vlistbox*/
   put " );"; /*end hlist */
   put ");";  /*end function*/   
   
   put "objRefNS:AddDataFilterContextBox = 1;";
   put "objRefNS:filterColumnsList = {};";  
   put "insertInto(objRefNS:filterColumnsList, {{""&TimeLabel"", {}}});";
   %if %upcase(&TimePoints) = YES %then %do; 
       put "insertInto(objRefNS:filterColumnsList, {{""&TPLabel"", {}}});";
   %end;
   put "If(!reportRefNS:useGlobalSubjectFilterWithinReview(),";
   put "objRefNS:ReportDataFilterReferenceList = reportRefNS:createReportFilter(objRefNS:ftd, objRefNS:filterColumnsList);";
   put ",";
   put "objRefNS:ReportDataFilterReferenceList = reportRefNS:createReportFilter(objRefNS:ftd, objRefNS:filterColumnsList,1);";
   put ");";

   put "  objRefNS:reportACupdates = Expr(";
   %do i = 1 %to &nvals;
      %if %Upcase(&DisplayMeanTrends) = YES %then %do;
         * S1042240, Chinese title was deleted;
         * kemicl: S1110144, fix in JMP need to delete box again to get rid of where statement;
         put "    try(objRefNS:vgbm&i[Text Box(1)]<<Delete;);";
         put "    try((objRefNS:gbm&i<<report)[framebox(1)]<<FrameSize(objRefNS:fsize,0.35*objRefNS:fsize););";
      %end;
      put "    try(objRefNS:vgb&i[Text Box(1)]<<Delete;);"; 
      put "    try((objRefNS:gb&i<<report)[framebox(1)]<<FrameSize(objRefNS:fssize,0.35*objRefNS:fssize););";     
   %end;
   put "  );";
   put 'InsertInto(objRefNS:DataList,{{"objRefNS:ftd"}});';
   %if ^%symexist(DOMAINLABEL_&FDomain) %then %let DOMAINLABEL_&FDomain = %nrbquote(&FDomain);
   put "InsertInto(objRefNS:TabButtonList, expr(locale:fill(locale:get(""XSubjectTimeTrends_Text""),{""&&DOMAINLABEL_&FDomain""})));";
   put 'InsertInto(objRefNS:TabCodeList,expr(objRefNS:spfunc()));';
   put 'InsertInto(objRefNS:TabAfterCodeList, expr(objRefNS:reportACupdates));';
   put 'InsertInto(objRefNS:TabOpenList,1);';
   put "InsertInto(objRefNS:CreateReportList,{{objRefNS:GBvlb2}});";

   %SubjectDrillDowns;
   put 'objRefNS:ActionDataTableList = {{{"objRefNS:ftd"},{"objRefNS:ftd"},{"objRefNS:ftd"},{"objRefNS:ftd"},{"objRefNS:ftd"}}};';

run;

%PackageInsertFile(jsl code from &ProcessName, &OutPath, &FindingsTimeTrendsScriptName, &OutDataName..sas7bdat, yes);

%exit:;
%ExitSDSProcess(&OutPath, &ProcessName, &syserr, &exiterror, &clockrunning);

%mend FindingsTimeTrends;

* run the macro;
%FindingsTimeTrends;


