
/************************ PRODUCT VALIDATION  ******************
 *
 *      NAME: HysLawScreening_LB001.sas
 *    REPORT: Hy's Law Screening JMPC7.1
 *   PURPOSE: Hy's Law Screening Validation Program for Nicardipine Study
 *   DEFECTS: 
 *     NOTES: Use Actual Treatment, Upper Limit of Normal, Last recorded pre-dose measurement 
 *     NOTES: NO Discrepancy found between JMPC Results and Validation Results

 *****************************************************************/
title1 "HysLawScreening_LB001.sas: Hy's Law Screening Validation Program";
title2 'Use Actual Treatment, Upper Limit of Normal, Last recorded pre-dose measurement';

libname sdtm "&SDTMPATH";
libname adam "&ADAMPATH";

/* Merge LB and ADSL datasets to get treatment in LB data */
data lb;
 merge sdtm.lb adam.adsl(keep=usubjid trt01p saffl where=(saffl='Y' and trt01p ne 'Screen Failure') in=a);
 by usubjid;
 if a;
run;

/* Subset data on Tests */
/* Normalize lab results based on upper limit of normal */
/* Flag ALT or AST >= 3*ULN and BILI >= 2*ULN */
data hys1;
 set lb(where=(lbtestcd in ('ALT','AST','BILI','ALP')));
 normtest=round(lbstresn/LBSTNRHI,0.01);
 if lbtestcd in ('ALT','AST') and lbstresn>=3*lbstnrhi>. then flagalt='Y';
 if lbtestcd='BILI' and lbstresn>=2*lbstnrhi>. then flagbili='Y';
run;

/* Get the maximum value per usubjid per lab test */
proc means data=hys1 noprint;
 by usubjid lbtestcd lbtest;
 var normtest;
 output out=peaks max=max;
run;

data peaks2;
 set peaks;
 normtest=round(max,0.01);
 keep usubjid lbtestcd lbtest max normtest;
run;

/* Merge peak values back in */
proc sort data=hys1; by usubjid lbtestcd lbtest normtest; run;
data hys2;
 merge hys1 peaks2(in=a);
 by usubjid lbtestcd lbtest normtest;
 if a then peakflag="Y";
 keep usubjid trt01p lbtestcd lbtest normtest max flagalt flagbili lbdy peakflag;
run;

proc sort data=hys2; by usubjid lbdy lbtestcd normtest; run;
data hys3;
 set hys2;
 by usubjid lbdy lbtestcd normtest;
 if last.lbtestcd;
run;

/* Get possible Hy's Law cases */
data hys4;
 merge hys3(keep=usubjid trt01p flagalt lbdy where=(flagalt="Y"))
       hys3(keep=usubjid trt01p flagbili lbdy where=(flagbili="Y"));
 by usubjid lbdy;
 if flagalt="Y" and flagbili="Y";
 keep usubjid lbdy;
run;

/* Get peak lab values as variables */
data hys5;
 merge hys3(keep=usubjid trt01p lbtestcd normtest peakflag where=(lbtestcd="ALT" and peakflag="Y") rename=(normtest=ALT))
       hys3(keep=usubjid trt01p lbtestcd normtest peakflag where=(lbtestcd="AST" and peakflag="Y") rename=(normtest=AST))
	   hys3(keep=usubjid trt01p lbtestcd normtest peakflag where=(lbtestcd="BILI" and peakflag="Y") rename=(normtest=BILI))
	   hys3(keep=usubjid trt01p lbtestcd normtest peakflag where=(lbtestcd="ALP" and peakflag="Y") rename=(normtest=ALP));
 by usubjid;
 keep usubjid alt ast bili alp trt01p;
run;

/* Merge peak values with possible Hy's Law cases */
data yes_hys;
 set hys4;
 by usubjid lbdy;
 if first.usubjid;
 label lbdy="First Day of Possible Hys Law Event";
run;

proc sort data=hys5 out=peaks3 nodupkey; by usubjid; run;
data hys6;
 merge yes_hys(in=a) peaks3;
 by usubjid;
 if a then hys_law="Yes";
  else hys_law="No";
run;

/* Merge in elevated AT tests */
data elev;
 set hys3(where=(flagalt="Y"));
 by usubjid lbdy;
 if first.usubjid;
 keep usubjid trt01p lbdy;
 rename lbdy=Elev_AT_day;
 label lbdy = "First Day of AT Elevation";
run;

data hys7;
 merge elev(in=a) hys6;
 by usubjid trt01p;
 if a then elevatedAT='Yes';
  else elevatedAT='No';
run;

/* Merge in Age, Sex, Race, and Site ID */
data hys8;
 merge adam.adsl(keep=usubjid age sex race siteid) hys7(in=a);
 by usubjid;
 if a;
run;

/* Output dataset for Liver Test Elevations Plot, */
/* Scatterplots and Contingency Analysis, and Distributions */
libname outdata "&OUTPUTD";
data outdata.HysLawScreening_LB001;
 set hys8;
run;

/* AT Test Elevation and Possible Hy's Law Cases table */
proc sort data=hys8; by trt01p; run;
proc freq data=hys8 noprint;
 by trt01p;
 tables elevatedAT*hys_law/out=table1;
run;

data table1b;
 set table1;
 nper=put(count,3.)||" ("||put(percent,5.1)||"%)";
run;

proc sort data=table1b; by descending elevatedAT descending hys_law; run;
proc transpose data=table1b out=table1c;
 by descending elevatedAT descending hys_law;
 var nper;
 id trt01p;
 idlabel trt01p;
run;

/* Test counts and percents tables */
proc sort data=hys8 out=uln_shell0(keep=usubjid trt01p) nodupkey; by usubjid; run;
data uln_shell;
 length lbtestcd $6;
 set uln_shell0;
 do lbtestcd="ALP","ALT","AST","BILI";
  output;
 end;
run;

proc sort data=lb; by usubjid lbtestcd; run;
data uln;
 length uln_flag $200;
 merge lb(where=(lbtestcd in ('ALT','AST','BILI','ALP'))) uln_shell;
 by usubjid lbtestcd;
 if .<lbstresn<2*lbstnrhi then do; uln_flag='Less than 2x'; ord=1; end;
 if .<2*lbstnrhi<=lbstresn<5*lbstnrhi then do; uln_flag='Between 2x and 5x'; ord=2; end;
 if .<5*lbstnrhi<=lbstresn<10*lbstnrhi then do; uln_flag='Between 5x and 10x'; ord=3; end;
 if .<10*lbstnrhi<=lbstresn<20*lbstnrhi then do; uln_flag='Between 10x and 20x'; ord=4; end;
 if .<20*lbstnrhi<=lbstresn then do; uln_flag='Greater than 20x'; ord=5; end;
 if lbstresn=. then do; uln_flag="Missing Test Result"; ord=6; end;
run;

proc sort data=uln out=uln2; by trt01p lbtestcd usubjid lbstresn; run;
data uln3;
 set uln2;
 by trt01p lbtestcd usubjid lbstresn;
 if last.usubjid;
run;

proc freq data=uln3 noprint;
 by trt01p lbtestcd;
 tables uln_flag*ord/out=uln_freq;
run;

data uln_freq2;
 set uln_freq;
 nper=put(count,3.)||" ("||put(percent,5.1)||"%)";
run;

proc sort data=uln_freq2; by lbtestcd ord trt01p; run;
proc transpose data=uln_freq2 out=t_uln;
 by  lbtestcd ord uln_flag;
 var nper;
 id trt01p;
 idlabel trt01p;
run;

/* Peak Liver Lab Tests per Subject by Study Day */
data byday;
 merge hys3(drop=flagalt flagbili max peakflag where=(lbtestcd="ALT") rename=(normtest=ALT))
       hys3(drop=flagalt flagbili max peakflag where=(lbtestcd="AST") rename=(normtest=AST))
	   hys3(drop=flagalt flagbili max peakflag where=(lbtestcd="BILI") rename=(normtest=BILI))
	   hys3(drop=flagalt flagbili max peakflag where=(lbtestcd="ALP") rename=(normtest=ALP));
 by usubjid lbdy;
 drop lbtestcd lbtest;
run;

data outdata.HysLawScreening_LB001_by_day;
 set byday;
run;

/* Missing Lab Test Summary Tables */
proc sort data=adam.adsl out=dm_miss(keep=usubjid trt01p); by usubjid; where saffl='Y' and trt01p ne 'Screen Failure'; run;

data dmshell;
 length lbtestcd $6;
 set dm_miss;
 do lbtestcd="ALP","ALT","AST","BILI";
  output;
 end;
run;

data test_miss;
 merge dmshell(in=dm) hys1(in=lb);
 by usubjid lbtestcd;
 if dm and ^lb;
 keep usubjid trt01p lbtestcd;
run;

proc sort data=test_miss; by trt01p lbtestcd; run;
proc freq data=test_miss noprint;
 by trt01p;
 tables lbtestcd/out=missed_tests(drop=percent);
run;

proc sort data=missed_tests; by lbtestcd; run;
proc transpose data=missed_tests out=t_missed_tests;
 by lbtestcd;
 var count;
 id trt01p;
 idlabel trt01p;
run;

data all_miss;
 merge dm_miss(in=dm) hys1(in=lb);
 by usubjid;
 if dm and ^lb;
 keep usubjid trt01p;
run;

proc sort data=all_miss; by trt01p; run;
proc freq data=all_miss noprint;
 tables trt01p/out=missed_all_tests(drop=percent);
run;

proc transpose data=missed_all_tests out=t_missed_all_tests;
 var count;
 id trt01p;
 idlabel trt01p;
run;

**** Use Proc Report to write the tables to file;
options nodate nonumber missing = ' ';

filename pdfOutF "&OUTPUTD/HysLawScreening_LB001.pdf";

ods escapechar='#';
ods pdf style =htmlblue file=pdfOutF;

proc report data=table1c
	nowindows
	split="|";
	
	columns elevatedAT hys_law NIC__15 Placebo;

	define elevatedAT /order order=internal descending width =19 "Elevated AT Tests";
	define hys_law  /order order=internal descending width =19 "Possible Hy's Law Case";
	define NIC__15  /display center width=19 "NIC 15";
	define Placebo  /display center width=19 "Placebo";

	compute after elevatedAT;
		line '#{newline}';
	endcomp;

title3 j=c "AT Test Elevation and Possible Hy's Law Cases";
run;

proc report data=t_uln
	nowindows
	split="|";
	
	columns lbtestcd ord uln_flag NIC__15 Placebo;

	define ord      / order order=internal noprint;
	define lbtestcd /order width =19 "Lab Test";
	define uln_flag /order width =19 "Test Elevation";
	define NIC__15  /display center width=19 "NIC 15";
	define Placebo  /display center width=19 "Placebo";

	compute after lbtestcd;
		line '#{newline}';
	endcomp;

title3 j=c "Counts and Percents Tables";
run;

proc report data=t_missed_tests
	nowindows
	split="|";
	
	columns lbtestcd NIC__15 Placebo;

	define lbtestcd /order width =19 "Lab Test";
	define NIC__15  /display center width=19 "NIC 15";
	define Placebo  /display center width=19 "Placebo";

title3 j=c "Counts of Subjects Missing Liver Lab Records";
run;

proc report data=t_missed_all_tests
	nowindows
	split="|";
	
	columns NIC__15 Placebo;

	define NIC__15  /display center width=19 "NIC 15";
	define Placebo  /display center width=19 "Placebo";

title3 j=c "Counts of Subjects Missing All Tests";
run;

ods pdf close;